@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-pipelines-github",
-    "0.4.105",
+    "0.4.116",
     __name__[0:-6],
-    "cdk-pipelines-github@0.4.105.jsii.tgz",
+    "cdk-pipelines-github@0.4.116.jsii.tgz",
 )
 
 __all__ = [
